@@ -1,21 +1,22 @@
 /*
  *      Copyright (C) 2002 Fabio Fiorina
  *
- * This file is part of LIBASN1.
+ * This file is part of LIBTASN1.
  *
- * LIBASN1 is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
- * LIBASN1 is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA
  */
 
 
@@ -39,7 +40,7 @@
   #include <getopt.h>
 #endif
 
-char version_man[] = "asn1Coding (GNU libasn1) " VERSION;
+char version_man[] = "asn1Coding (GNU libtasn1) " VERSION;
 
 char help_man[] = "asn1Coding generates a DER encoding from a file\n"
                   "with ASN1 definitions and another one with assignments.\n"
@@ -239,7 +240,7 @@ main(int argc,char *argv[])
    printf("asn1Coding: %s\n",errorDescription);
    break;
  default:
-   printf("libasn1 ERROR: %s\n",libtasn1_strerror(asn1_result));
+   printf("libtasn1 ERROR: %s\n",libtasn1_strerror(asn1_result));
  }
 
  if(asn1_result != ASN1_SUCCESS){
@@ -270,7 +271,7 @@ main(int argc,char *argv[])
      asn1_result=asn1_write_value(structure,varName,value,0); 
 
    if(asn1_result != ASN1_SUCCESS){
-     printf("libasn1 ERROR: %s\n",libtasn1_strerror(asn1_result));
+     printf("libtasn1 ERROR: %s\n",libtasn1_strerror(asn1_result));
      
      asn1_delete_structure(&definitions);
      asn1_delete_structure(&structure);
